@@ -1,7 +1,7 @@
 revTransform <-
-function (x, data, qu, th = 0, sigma = 1, xi = 0, method = "mixture") {
-   if (!is.element(method, c("mixture", "empirical")))
-       stop("method should be 'mixture' or 'empirical'")
+    function (x, data, qu, th = 0, sigma = 1, xi = 0,
+              method = c("mixture", "empirical")) {
+   method <- match.arg(method)
 
    n <- length(data)
    probs <- (1:n)/(n + 1)
